# Table of Contents

- [fact-sheet-completeness](<./fact-sheet-completeness.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Fact Sheet Completeness](<./Fact-Sheet-Completeness.md>)
  - [Introduction](<./Fact-Sheet-Completeness/Introduction.md>)
  - [Completion Score Calculation](<./Fact-Sheet-Completeness/Completion-Score-Calculation.md>)
  - [Modifying Completion Weights](<./Fact-Sheet-Completeness/Modifying-Completion-Weights.md>)
  - [Was this page helpful?](<./Fact-Sheet-Completeness/Was-this-page-helpful.md>)
